![alt text](http://jobase.org/images/logo.png)

JoBase is aimed at beginner coders who want to make games with Python.
It has been built to make coding fun and intuitive.
JoBase is built on the Arcade library.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install JoBase.

```bash

pip install JoBase

```

If you want to install via GitHub instead, make sure you download the Arcade library as well.

## Get Started

To get started, follow the steps at [jobase.org](http://jobase.org/).

## License

[GNU General Public License v3.0](https://choosealicense.com/licenses/gpl-3.0/)